# streamlit-dsfr

VueDsfr components for Streamlit


## Installation instructions

```sh
pip install streamlit-dsfr
```


## Usage instructions

```python
import streamlit as st

from streamlit_dsfr import st_dsfr_button

value = st_dsfr_button()
st.write(value)
```
